@@ -1,6 +1,6 @@
 package Grimlock::Schema::Result::Entry;
 {
-  $Grimlock::Schema::Result::Entry::VERSION = '0.06';
+  $Grimlock::Schema::Result::Entry::VERSION = '0.07';
 }
 
 use Grimlock::Schema::Candy -components => [
@@ -80,10 +80,6 @@ column published => {
 
 belongs_to 'author' => 'Grimlock::Schema::Result::User', {
   'foreign.userid' => 'self.author',
-},
-{
-  cascade_delete => 1,
-  cascade_update => 1
 };
 
 belongs_to 'parent' => __PACKAGE__, {
@@ -91,8 +87,6 @@ belongs_to 'parent' => __PACKAGE__, {
 },
 {
   join_type => 'LEFT',
-  cascade_delete => 1,
-  cascade_update => 1
 };
 
 has_many 'children' => __PACKAGE__, {
@@ -161,4 +155,39 @@ sub created_at {
   return $date_time;
 }
 
+
+sub TO_JSON {
+  my $self = shift;
+  return {
+    reply_count => $self->reply_count,
+    children => $self->children_TO_JSON,
+    parent   => $self->parent,
+    body     => $self->body,
+    %{ $self->next::method },
+  }
+}
+
+sub children_TO_JSON {
+  my $self = shift;
+  my $children_rs = $self->children;
+  my @child_collection;
+  push @child_collection, {
+    entryid => $_->entryid,
+    title   => $_->title,
+    display_title => $_->display_title,
+    path    => $_->path,
+    parent  => $_->parent,
+    body    => $_->body,
+    author  => $_->author,
+    created_at => $_->created_at . "",
+    updated_at => $_->updated_at . "",
+    published => $_->published,
+    reply_count => $_->reply_count,
+    children => $_->children_TO_JSON,
+    parent   => $_->parent,
+  } for $children_rs->all;
+  
+  return \@child_collection;
+}
+
 1;
